NLOpt Python
============

[![PyPI version](https://badge.fury.io/py/nlopt.svg)](https://badge.fury.io/py/nlopt)
[![Windows](https://ci.appveyor.com/api/projects/status/ffpoxdg2p49sagc7?svg=true)](https://ci.appveyor.com/project/HDembinski/nlopt-python)
![Linux and MacOS](https://github.com/HDembinski/nlopt-python/workflows/Build/badge.svg)

This project builds Python wheels for the NLOpt library. NLOpt contains various routines for non-linear optimization.

## Versions supported

The project supports Python versions 3.6+ and above for Windows, MacOS, and Linux.

## Installation

```bash
pip install nlopt
```

## Documentation

For more information on how to use NLOpt, refer to the [documentation](https://nlopt.readthedocs.io/en/latest/NLopt_Python_Reference/).
